@@ -121,7 +121,7 @@ namespace hy_global {
                      kErrorStringDatasetRefIndexError ("Dataset index reference out of range"),
                      kErrorStringMatrixExportError    ("Export matrix called with a non-polynomial matrix argument"),
                      kErrorStringNullOperand          ("Attempting to operate on an undefined value; this is probably the result of an earlier 'soft' error condition"),
-                     kHyPhyVersion  = _String ("2.5.24"),
+                     kHyPhyVersion  = _String ("2.5.25"),
     
                     kNoneToken = "None",
                     kNullToken = "null",
@@ -429,7 +429,8 @@ namespace hy_global {
 #endif
         
         if (hy_env::cli_env_settings.nonempty()) {
-            _ExecutionList (hy_env::cli_env_settings).Execute();
+            _StringBuffer code (hy_env::cli_env_settings);
+            _ExecutionList (code).Execute();
         }
         return hy_error_log_file && hy_message_log_file;
     }
